@@ -14,7 +14,7 @@ package MCE::Core::Input::Handle;
 use strict;
 use warnings;
 
-our $VERSION = '1.876';
+our $VERSION = '1.884';
 
 ## Items below are folded into MCE.
 
@@ -48,10 +48,9 @@ sub _worker_read_handle {
    _croak('MCE::_worker_read_handle: (user_func) is not specified')
       unless (defined $self->{user_func});
 
-   my $_DAT_LOCK    = $self->{_dat_lock};
+   my $_is_MSWin32  = ($^O eq 'MSWin32') ? 1 : 0;
    my $_QUE_R_SOCK  = $self->{_que_r_sock};
    my $_QUE_W_SOCK  = $self->{_que_w_sock};
-   my $_lock_chn    = $self->{_lock_chn};
    my $_chunk_size  = $self->{chunk_size};
    my $_use_slurpio = $self->{use_slurpio};
    my $_parallel_io = $self->{parallel_io};
@@ -59,24 +58,21 @@ sub _worker_read_handle {
    my $_wuf         = $self->{_wuf};
 
    my ($_data_size, $_next, $_chunk_id, $_offset_pos, $_IN_FILE, $_tmp_cs);
-   my ($_dat_ex, $_dat_un, $_pid, $_chop_len, $_chop_str, $_p);
+   my ($_DAT_LOCK, $_dat_ex, $_dat_un, $_pid, $_chop_len, $_chop_str, $_p);
 
-   if ($_lock_chn) {
-      $_pid = $INC{'threads.pm'} ? $$ .'.'. threads->tid() : $$;
+   $_pid = $INC{'threads.pm'} ? $$ .'.'. threads->tid() : $$;
 
-      # inlined for performance
-      if ($self->{_data_channels} > 5) {
-         $_DAT_LOCK = $self->{'_mutex_'.( $self->{_wid} % 5 + 1 )};
-      }
-      $_dat_ex = sub {
-         MCE::Util::_sysread($_DAT_LOCK->{_r_sock}, my($b), 1), $_DAT_LOCK->{ $_pid } = 1
-            unless $_DAT_LOCK->{ $_pid };
-      };
-      $_dat_un = sub {
-         syswrite($_DAT_LOCK->{_w_sock}, '0'), $_DAT_LOCK->{ $_pid } = 0
-            if $_DAT_LOCK->{ $_pid };
-      };
-   }
+   # inlined for performance
+   $_DAT_LOCK = $self->{'_mutex_'.( $self->{_wid} % 2 + 10 )};
+   $_dat_ex = sub {
+      MCE::Util::_sock_ready($_DAT_LOCK->{_r_sock}) if $_is_MSWin32;
+      MCE::Util::_sysread($_DAT_LOCK->{_r_sock}, my($b), 1), $_DAT_LOCK->{ $_pid } = 1
+         unless $_DAT_LOCK->{ $_pid };
+   };
+   $_dat_un = sub {
+      syswrite($_DAT_LOCK->{_w_sock}, '0'), $_DAT_LOCK->{ $_pid } = 0
+         if $_DAT_LOCK->{ $_pid };
+   };
 
    if (length $_RS > 1 && substr($_RS, 0, 1) eq "\n") {
       $_chop_str = substr($_RS, 1);
@@ -109,14 +105,15 @@ sub _worker_read_handle {
       $_ = '';
 
       ## Obtain the next chunk_id and offset position.
-      $_dat_ex->() if $_lock_chn;
+      $_dat_ex->();
+      MCE::Util::_sock_ready($_QUE_R_SOCK) if $_is_MSWin32;
       MCE::Util::_sysread($_QUE_R_SOCK, $_next, $_que_read_size);
 
       ($_chunk_id, $_offset_pos) = unpack($_que_template, $_next);
 
       if ($_offset_pos >= $_data_size) {
          syswrite($_QUE_W_SOCK, pack($_que_template, 0, $_offset_pos));
-         $_dat_un->() if $_lock_chn;
+         $_dat_un->();
          close $_IN_FILE; undef $_IN_FILE;
          return;
       }
@@ -173,7 +170,7 @@ sub _worker_read_handle {
          syswrite(
             $_QUE_W_SOCK, pack($_que_template, $_chunk_id, tell $_IN_FILE)
          );
-         $_dat_un->() if $_lock_chn;
+         $_dat_un->();
       }
       else {                                      # Large chunk.
          local $/ = $_RS if ($/ ne $_RS);
@@ -183,7 +180,7 @@ sub _worker_read_handle {
                $_QUE_W_SOCK,
                pack($_que_template, $_chunk_id, $_offset_pos + $_chunk_size)
             );
-            $_dat_un->() if $_lock_chn;
+            $_dat_un->();
 
             $_tmp_cs = $_chunk_size;
             seek $_IN_FILE, $_offset_pos, 0;
@@ -219,7 +216,7 @@ sub _worker_read_handle {
             syswrite(
                $_QUE_W_SOCK, pack($_que_template, $_chunk_id, tell $_IN_FILE)
             );
-            $_dat_un->() if $_lock_chn;
+            $_dat_un->();
          }
       }
 
@@ -280,7 +277,7 @@ MCE::Core::Input::Handle - File path and Scalar reference input reader
 
 =head1 VERSION
 
-This document describes MCE::Core::Input::Handle version 1.876
+This document describes MCE::Core::Input::Handle version 1.884
 
 =head1 DESCRIPTION
 
