@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.866';
+our $VERSION = '1.884';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -46,15 +46,15 @@ sub import {
    my $_p = $_def->{$_pkg} = {
       MAX_WORKERS => 'auto',
       CHUNK_SIZE  => 'auto',
-      FAST        => 0,
    };
 
    ## Import functions.
-   no strict 'refs'; no warnings 'redefine';
-
-   *{ $_pkg.'::mce_step_f' } = \&run_file;
-   *{ $_pkg.'::mce_step_s' } = \&run_seq;
-   *{ $_pkg.'::mce_step'   } = \&run;
+   if ($_pkg !~ /^MCE::/) {
+      no strict 'refs'; no warnings 'redefine';
+      *{ $_pkg.'::mce_step_f' } = \&run_file;
+      *{ $_pkg.'::mce_step_s' } = \&run_seq;
+      *{ $_pkg.'::mce_step'   } = \&run;
+   }
 
    ## Process module arguments.
    while ( my $_argument = shift ) {
@@ -65,7 +65,10 @@ sub import {
       $_p->{TMP_DIR}     = shift, next if ( $_arg eq 'tmp_dir' );
       $_p->{FREEZE}      = shift, next if ( $_arg eq 'freeze' );
       $_p->{THAW}        = shift, next if ( $_arg eq 'thaw' );
-      $_p->{FAST}        = shift, next if ( $_arg eq 'fast' );
+      $_p->{INIT_RELAY}  = shift, next if ( $_arg eq 'init_relay' );
+      $_p->{USE_THREADS} = shift, next if ( $_arg eq 'use_threads' );
+
+                           shift, next if ( $_arg eq 'fast' ); # ignored
 
       ## Sereal 3.015+, if available, is used automatically by MCE 1.8+.
       if ( $_arg eq 'sereal' ) {
@@ -131,11 +134,7 @@ sub _task_end {
       my $_task_id = $self->{_task_id};
 
       if ($_task_id < $_last_task_id->{$_pid}) {
-         if (scalar @_ > 1 || ref $_[0] || !defined $_[0]) {
-            $_queue->{$_pid}[$_task_id]->enqueue($self->freeze([ @_ ]).'1');
-         } else {
-            $_queue->{$_pid}[$_task_id]->enqueue($_[0].'0');
-         }
+         $_queue->{$_pid}[$_task_id]->enqueue($self->freeze([ @_ ]));
       }
       else {
          _croak('MCE::step: method is not allowed by the last task');
@@ -163,16 +162,11 @@ sub _task_end {
 
       if ($_task_id < $_last_task_id->{$_pid}) {
          if (scalar @_ > 1) {
-            my @_items = map {
-               (ref $_ || !defined $_) ? $self->freeze([ $_ ]).'1' : $_.'0';
-            } @_;
+            my @_items = map { $self->freeze([ $_ ]) } @_;
             $_queue->{$_pid}[$_task_id]->enqueue(@_items);
          }
-         elsif (!defined $_[0] || ref $_[0]) {
-            $_queue->{$_pid}[$_task_id]->enqueue($self->freeze([ @_ ]).'1');
-         }
          else {
-            $_queue->{$_pid}[$_task_id]->enqueue($_[0].'0');
+            $_queue->{$_pid}[$_task_id]->enqueue($self->freeze([ @_ ]));
          }
       }
       else {
@@ -203,16 +197,11 @@ sub _task_end {
 
       if ($_task_id < $_last_task_id->{$_pid}) {
          if (scalar @_ > 1) {
-            my @_items = map {
-               (ref $_ || !defined $_) ? $self->freeze([ $_ ]).'1' : $_.'0';
-            } @_;
+            my @_items = map { $self->freeze([ $_ ]) } @_;
             $_queue->{$_pid}[$_task_id]->enqueuep($_p, @_items);
          }
-         elsif (!defined $_[0] || ref $_[0]) {
-            $_queue->{$_pid}[$_task_id]->enqueuep($_p, $self->freeze([ @_ ]).'1');
-         }
          else {
-            $_queue->{$_pid}[$_task_id]->enqueuep($_p, $_[0].'0');
+            $_queue->{$_pid}[$_task_id]->enqueuep($_p, $self->freeze([ @_ ]));
          }
       }
       else {
@@ -382,17 +371,17 @@ sub run_seq (@) {
          $_pos = $_i;
 
          if ($_r eq '' || $_r =~ /^Math::/) {
-            $_begin = $_[$_pos]; $_end = $_[$_pos + 1];
+            $_begin = $_[$_pos], $_end = $_[$_pos + 1];
             $_params->{$_pid}{sequence} = [
                $_[$_pos], $_[$_pos + 1], $_[$_pos + 2], $_[$_pos + 3]
             ];
          }
          elsif ($_r eq 'HASH') {
-            $_begin = $_[$_pos]->{begin}; $_end = $_[$_pos]->{end};
+            $_begin = $_[$_pos]->{begin}, $_end = $_[$_pos]->{end};
             $_params->{$_pid}{sequence} = $_[$_pos];
          }
          elsif ($_r eq 'ARRAY') {
-            $_begin = $_[$_pos]->[0]; $_end = $_[$_pos]->[1];
+            $_begin = $_[$_pos]->[0], $_end = $_[$_pos]->[1];
             $_params->{$_pid}{sequence} = $_[$_pos];
          }
 
@@ -532,7 +521,7 @@ sub run (@) {
       my $_Q = $_queue->{$_pid};
       pop(@{ $_Q })->DESTROY for (@_code .. @{ $_Q });
 
-      push @{ $_Q }, MCE::Queue->new(fast => $_def->{$_pkg}{FAST}, await => 1)
+      push @{ $_Q }, MCE::Queue->new(await => 1)
          for (@{ $_Q } .. @_code - 2);
 
       $_last_task_id->{$_pid} = @_code - 1;
@@ -567,7 +556,7 @@ sub run (@) {
          }
       }
 
-      for my $_k (qw/ tmp_dir freeze thaw /) {
+      for my $_k (qw/ tmp_dir freeze thaw init_relay use_threads /) {
          $_opts{$_k} = $_def->{$_pkg}{uc($_k)}
             if (exists $_def->{$_pkg}{uc($_k)} && !exists $_opts{$_k});
       }
@@ -658,12 +647,8 @@ sub _gen_user_func {
       _MCE_STEP__NEXT:
 
       while (defined (local $_ = $_q_in->dequeue())) {
-         if (chop $_) {
-            my $_args = $_mce->thaw($_);  $_ = $_args->[0];
-            $_code->($_mce, @{ $_args });
-         } else {
-            $_code->($_mce, $_);
-         }
+         my $_args = $_mce->thaw($_);  $_ = $_args->[0];
+         $_code->($_mce, @{ $_args });
       }
 
       _MCE_STEP__LAST:
@@ -715,7 +700,7 @@ MCE::Step - Parallel step model for building creative steps
 
 =head1 VERSION
 
-This document describes MCE::Step version 1.866
+This document describes MCE::Step version 1.884
 
 =head1 DESCRIPTION
 
@@ -896,9 +881,9 @@ inside the first block. Hence, the block is called once per each item.
  ## Exports mce_step, mce_step_f, and mce_step_s
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 1
- };
+ );
 
  ## Array or array_ref
  mce_step sub { do_work($_) }, 1..10000;
@@ -932,9 +917,9 @@ This means having to loop through the chunk from inside the first block.
 
  use MCE::Step;
 
- MCE::Step::init {          ## Chunk_size defaults to 'auto' when
+ MCE::Step->init(           ## Chunk_size defaults to 'auto' when
     chunk_size => 'auto'    ## not specified. Therefore, the init
- };                         ## function may be omitted.
+ );                         ## function may be omitted.
 
  ## Syntax is shown for mce_step for demonstration purposes.
  ## Looping inside the block is the same for mce_step_f and
@@ -965,6 +950,7 @@ choosing 1 for chunk_size is fine.
 =head1 OVERRIDING DEFAULTS
 
 The following list options which may be overridden when loading the module.
+The fast option is obsolete in 1.867 onwards; ignored if specified.
 
  use Sereal qw( encode_sereal decode_sereal );
  use CBOR::XS qw( encode_cbor decode_cbor );
@@ -976,7 +962,8 @@ The following list options which may be overridden when loading the module.
      tmp_dir => "/path/to/app/tmp",   # $MCE::Signal::tmp_dir
      freeze => \&encode_sereal,       # \&Storable::freeze
      thaw => \&decode_sereal,         # \&Storable::thaw
-     fast => 1                        # Default 0 (fast dequeue)
+     init_relay => 0,                 # Default undef; MCE 1.882+
+     use_threads => 0,                # Default undef; MCE 1.882+
  ;
 
 From MCE 1.8 onwards, Sereal 3.015+ is loaded automatically if available.
@@ -1000,7 +987,7 @@ both gather and bounds_only options may be specified when calling init
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 1, max_workers => 4,
 
     user_begin => sub {
@@ -1010,7 +997,7 @@ both gather and bounds_only options may be specified when calling init
     user_end => sub {
        print "## ", MCE->wid, " completed\n";
     }
- };
+ );
 
  my %a = mce_step sub { MCE->gather($_, $_ * $_) }, 1..100;
 
@@ -1036,7 +1023,7 @@ both gather and bounds_only options may be specified when calling init
  7569 7744 7921 8100 8281 8464 8649 8836 9025 9216 9409 9604 9801
  10000
 
-Like with MCE::Step::init above, MCE options may be specified using an
+Like with MCE::Step->init above, MCE options may be specified using an
 anonymous hash for the first argument. Notice how task_name, max_workers,
 and use_threads can take an anonymous array for setting uniquely per
 each code block.
@@ -1165,10 +1152,10 @@ needed after the block.
 
  # Here, options are specified via init
 
- MCE::Step::init {
+ MCE::Step->init(
     max_workers => [  1,   3  ],
     task_name   => [ 'p', 'c' ]
- };
+ );
 
  mce_step \&producer, \&consumers;
 
@@ -1253,10 +1240,10 @@ Time was measured using 1 worker to emphasize the difference.
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     max_workers => 1, chunk_size => 1_250_000,
     bounds_only => 1
- };
+ );
 
  # Typically, the input scalar $_ contains the sequence number
  # when chunk_size => 1, unless the bounds_only option is set
@@ -1299,14 +1286,14 @@ Time was measured using 1 worker to emphasize the difference.
 =back
 
 An iterator reference may be specified for input_data. The only other way
-is to specify input_data via MCE::Step::init. This prevents MCE::Step from
+is to specify input_data via MCE::Step->init. This prevents MCE::Step from
 configuring the iterator reference as another user task which will not work.
 
 Iterators are described under section "SYNTAX for INPUT_DATA" at L<MCE::Core>.
 
- MCE::Step::init {
+ MCE::Step->init(
     input_data => iterator
- };
+ );
 
  mce_step sub { $_ };
 
@@ -1334,10 +1321,10 @@ sub-task.
     MCE->printf( "%d: %d, %03.06f\n", MCE->wid, $args[0], $args[1] );
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c' ],
     max_workers => [  1 ,  4  ]
- };
+ );
 
  mce_step \&provider, \&consumer;
 
@@ -1398,10 +1385,10 @@ will cause an error.
     MCE->printf( "D%d: %d, %03.06f\n", MCE->wid, $args->[0], $args->[1] );
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c', 'd' ],
     max_workers => [  2 ,  3 ,  3  ]
- };
+ );
 
  mce_step \&provider, \&consumer_c, \&consumer_d;
 
@@ -1457,10 +1444,10 @@ items pending in its queue.
     sleep 0.05;
  }
 
- MCE::Step::init {
+ MCE::Step->init(
     task_name   => [ 'p', 'c' ],
     max_workers => [  1 ,  4  ]
- };
+ );
 
  mce_step \&provider, \&consumer;
 
@@ -1603,9 +1590,9 @@ gathering data such as retaining output order.
  ## the case and depends on Perl. Pass a reference to a subroutine if
  ## workers must persist; e.g. mce_step { ... }, \&foo, 1..100000.
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 'auto', max_workers => 'auto'
- };
+ );
 
  for (1..2) {
     my @m2;
@@ -1628,7 +1615,7 @@ gathering data such as retaining output order.
     print scalar @m2, "\n";
  }
 
- MCE::Step::finish;
+ MCE::Step->finish;
 
 All 6 models support 'auto' for chunk_size unlike the Core API. Think of the
 models as the basis for providing JIT for MCE. They create the instance, tune
@@ -1684,13 +1671,13 @@ longer needed.
 
  use MCE::Step;
 
- MCE::Step::init {
+ MCE::Step->init(
     chunk_size => 20, max_workers => 'auto'
- };
+ );
 
  mce_step sub { ... }, 1..100;
 
- MCE::Step::finish;
+ MCE::Step->finish;
 
 =head1 INDEX
 
